==> peperit_2.0_estable.zip: themes/peperit/html_files/componentes/cesta/tipo_envio/linea_tipo_envio.php <==
<?php
	//---------------------------------------------------------------------------------------------------------
	// 16/Abril/2019
	// Versión 1.0 Formulario que muestra el tipo de envío
	//---------------------------------------------------------------------------------------------------------
	/*
		//Parámetros
			0 => Objeto tipo de envío actual
	*/
	$obTipoEnvio = Theme::getLastParam(1);
	$tipo_envio = CabeceraCesta::getShippingType();
	$nombre_tipo_envio = $obTipoEnvio->nombre;
	ob_start();
	?>
	$('.finalizar_compra .loading').show();
	$('.finalizar_compra .clase_estado_cesta.texto_estado').hide();
	$('.finalizar_compra .modulo_finalizar_compra').hide();
	var data = {'tipo_envio' : <?=$obTipoEnvio->codigo;?>};
	WS_data_update(
		'CabeceraCesta',
		'setShippingType',
		data,
		'*=\'bloque_tipo_envio\'|*=\'bloque_total_cesta\'',
		function(objeto){
			$('.finalizar_compra .loading').hide();
			$('.finalizar_compra .clase_estado_cesta.texto_estado').show();
			$('.finalizar_compra .modulo_finalizar_compra').show();
		}
	);	
	<?php
	$script_onclick = ob_get_clean();

	//PEdro 13/Mayo/2020 ==> Vamos a utilizar un banner en vez de meter directamente la imagen, para ello copiamos el código de marina y en ve de usar la url usamos la condición
	/*//Marina (22/04/2019) Añadimos un icono distinto según la forma de envio
	$src = Shop::$configuracion->url. _WS_THEMES_DIR_ . _WS_THEME_DIR_ . _WS_THEME_HTML_DIR_ . 'images/';

	$icono_envio = $src."dots.png";
	$alt=$nombre_tipo_envio;

	if(strpos(strtoupper($nombre_tipo_envio), "URGENTE") !== false 
		|| strpos(strtoupper($nombre_tipo_envio), "DOMICILIO") !== false
		|| strpos(strtoupper($nombre_tipo_envio), "TRANSPORTE") !== false ){
		$icono_envio=$src."camion.png";

	}else if(strpos(strtoupper($nombre_tipo_envio), "CORREO") !== false){
		$icono_envio=$src."correo.png";

	}else if(strpos(strtoupper($nombre_tipo_envio), "REEMBOLSO") !== false){
		$icono_envio=$src."reembolso.png";
	
	}else if(strpos(strtoupper($nombre_tipo_envio), "TIENDA") !== false){
		$icono_envio=$src."tienda.png";
	
	}else if(strpos(strtoupper($nombre_tipo_envio), "LIBROS") !== false){
		$icono_envio=$src."envio_libros.png";
	}*/
	$icono = 'envio-indeterminado';
	if(strpos(strtoupper($nombre_tipo_envio), "URGENTE") !== false 
		|| strpos(strtoupper($nombre_tipo_envio), "DOMICILIO") !== false
		|| strpos(strtoupper($nombre_tipo_envio), "TRANSPORTE") !== false ){
		$icono = 'camion';

	}else if(strpos(strtoupper($nombre_tipo_envio), "CORREO") !== false){
		$icono = 'correos';

	}else if(strpos(strtoupper($nombre_tipo_envio), "REEMBOLSO") !== false){
		$icono = 'contrareembolso';
	
	}else if(strpos(strtoupper($nombre_tipo_envio), "TIENDA") !== false){
		$icono = 'tienda';
	
	}else if(strpos(strtoupper($nombre_tipo_envio), "LIBROS") !== false){
		$icono = 'libros';
	}
?>
<div class="boton boton_envio <?=($obTipoEnvio->codigo == $tipo_envio)? 'active' :'' ;?>"  onclick="<?=$script_onclick;?>">
	<input type="radio" name="tipo_envio"  value="<?=$obTipoEnvio->codigo;?>" <?=($obTipoEnvio->codigo == $tipo_envio)? 'checked="checked"' :'' ;?> required="required" form="cesta_<?=Sections::$current_section;?>">
	<div class="icono_envio col-xs-2">
		<?php
			//Pedro 13/Mayo/2020 ==> Esta imagen la vamos a mostrar con un banner
			/*<img src="<?=$icono_envio;?>" border="0" alt="<?=$alt;?>">*/
			new Widget($_WH->GW('banner'), 'banner_icono_tipo_envio', $icono, 1, true);
		?>
	</div>
	<div class="texto col-xs-10">
		<div class="nombre_envio"><strong><?=$obTipoEnvio->nombre;?></strong></div>
		<div class="forma_envio"><strong><?=$obTipoEnvio->descripcion;?></strong></div>
		<div class="delivery_option_price"><?=number_format($obTipoEnvio->getGastosEnvio(), Shop::$configuracion->decimales, ",", ".");?>&euro;</div>
	</div>
</div>

==> peperit_2.1.01_estable.zip: themes/peperit/html_files/componentes/cesta/tipo_envio/linea_tipo_envio.php <==
<?php
	//---------------------------------------------------------------------------------------------------------
	// 16/Abril/2019
	// Versión 1.0 Formulario que muestra el tipo de envío
	//---------------------------------------------------------------------------------------------------------
	/*
		//Parámetros
			0 => Objeto tipo de envío actual
	*/
	$obTipoEnvio = Theme::getLastParam(1);
	$tipo_envio = CabeceraCesta::getShippingType();
	$nombre_tipo_envio = $obTipoEnvio->nombre;
	ob_start();
	?>
	$('.finalizar_compra .loading').show();
	$('.finalizar_compra .clase_estado_cesta.texto_estado').hide();
	$('.finalizar_compra .modulo_finalizar_compra').hide();
	var data = {'tipo_envio' : <?=$obTipoEnvio->codigo;?>};
	WS_data_update(
		'CabeceraCesta',
		'setShippingType',
		data,
		'*=\'bloque_tipo_envio\'|*=\'bloque_total_cesta\'',
		function(objeto){
			$('.finalizar_compra .loading').hide();
			$('.finalizar_compra .clase_estado_cesta.texto_estado').show();
			$('.finalizar_compra .modulo_finalizar_compra').show();
		}
	);	
	<?php
	$script_onclick = ob_get_clean();

	//PEdro 13/Mayo/2020 ==> Vamos a utilizar un banner en vez de meter directamente la imagen, para ello copiamos el código de marina y en ve de usar la url usamos la condición
	/*//Marina (22/04/2019) Añadimos un icono distinto según la forma de envio
	$src = Shop::$configuracion->url. _WS_THEMES_DIR_ . _WS_THEME_DIR_ . _WS_THEME_HTML_DIR_ . 'images/';

	$icono_envio = $src."dots.png";
	$alt=$nombre_tipo_envio;

	if(strpos(strtoupper($nombre_tipo_envio), "URGENTE") !== false 
		|| strpos(strtoupper($nombre_tipo_envio), "DOMICILIO") !== false
		|| strpos(strtoupper($nombre_tipo_envio), "TRANSPORTE") !== false ){
		$icono_envio=$src."camion.png";

	}else if(strpos(strtoupper($nombre_tipo_envio), "CORREO") !== false){
		$icono_envio=$src."correo.png";

	}else if(strpos(strtoupper($nombre_tipo_envio), "REEMBOLSO") !== false){
		$icono_envio=$src."reembolso.png";
	
	}else if(strpos(strtoupper($nombre_tipo_envio), "TIENDA") !== false){
		$icono_envio=$src."tienda.png";
	
	}else if(strpos(strtoupper($nombre_tipo_envio), "LIBROS") !== false){
		$icono_envio=$src."envio_libros.png";
	}*/
	$icono = 'envio-indeterminado';
	if(strpos(strtoupper($nombre_tipo_envio), "URGENTE") !== false 
		|| strpos(strtoupper($nombre_tipo_envio), "DOMICILIO") !== false
		|| strpos(strtoupper($nombre_tipo_envio), "TRANSPORTE") !== false ){
		$icono = 'camion';

	}else if(strpos(strtoupper($nombre_tipo_envio), "CORREO") !== false){
		$icono = 'correos';

	}else if(strpos(strtoupper($nombre_tipo_envio), "REEMBOLSO") !== false){
		$icono = 'contrareembolso';
	
	}else if(strpos(strtoupper($nombre_tipo_envio), "TIENDA") !== false){
		$icono = 'tienda';
	
	}else if(strpos(strtoupper($nombre_tipo_envio), "LIBROS") !== false){
		$icono = 'libros';
	}
?>
<div class="boton boton_envio <?=($obTipoEnvio->codigo == $tipo_envio)? 'active' :'' ;?>"  onclick="<?=$script_onclick;?>">
	<input type="radio" name="tipo_envio"  value="<?=$obTipoEnvio->codigo;?>" <?=($obTipoEnvio->codigo == $tipo_envio)? 'checked="checked"' :'' ;?> required="required" form="cesta_<?=Sections::$current_section;?>">
	<div class="icono_envio col-xs-2">
		<?php
			//Pedro 13/Mayo/2020 ==> Esta imagen la vamos a mostrar con un banner
			/*<img src="<?=$icono_envio;?>" border="0" alt="<?=$alt;?>">*/
			new Widget($_WH->GW('banner'), 'banner_icono_tipo_envio', $icono, 1, true);
		?>
	</div>
	<div class="texto col-xs-10">
		<div class="nombre_envio"><strong><?=$obTipoEnvio->nombre;?></strong></div>
		<?php
			//Marina(02/09/2020) reemplazo los \n del texto que llega del programa por saltos de línea con br
			$descripcion_envio = str_replace('\\n', '<br>', $obTipoEnvio->descripcion);
		?>
		<div class="forma_envio"><strong><?=$descripcion_envio;?></strong></div>
		<div class="delivery_option_price"><?=number_format($obTipoEnvio->getGastosEnvio(), Shop::$configuracion->decimales, ",", ".");?>&euro;</div>
	</div>
</div>
